@@ -5,13 +5,18 @@ from function_scheduling_distributed_framework import frame_config
 from function_scheduling_distributed_framework.consumers.base_consumer import ExceptionForRequeue, ExceptionForRetry, AbstractConsumer
 from function_scheduling_distributed_framework.factories.publisher_factotry import get_publisher
 from function_scheduling_distributed_framework.factories.consumer_factory import get_consumer
-from function_scheduling_distributed_framework.utils import nb_print, LogManager
+from function_scheduling_distributed_framework.utils import nb_print, patch_print, LogManager
 
 
 # noinspection PyPep8Naming
-def patch_frame_config(MONGO_CONNECT_URL: str = None, RABBITMQ_USER: str = None,
+def patch_frame_config(MONGO_CONNECT_URL: str = None,
+
+                       RABBITMQ_USER: str = None,
                        RABBITMQ_PASS: str = None, RABBITMQ_HOST: str = None,
-                       RABBITMQ_PORT: int = None, RABBITMQ_VIRTUAL_HOST: str = None, REDIS_HOST: str = None, REDIS_PASSWORD: str = None, REDIS_PORT: int = None, REDIS_DB: int = None,
+                       RABBITMQ_PORT: int = None, RABBITMQ_VIRTUAL_HOST: str = None,
+
+                       REDIS_HOST: str = None, REDIS_PASSWORD: str = None, REDIS_PORT: int = None, REDIS_DB: int = None,
+
                        NSQD_TCP_ADDRESSES: list = None,
                        NSQD_HTTP_CLIENT_HOST: str = None,
                        NSQD_HTTP_CLIENT_PORT: int = None,
